Build object from data - 从数据中构建对象
=========================================

下面这个装饰器就是各知乎类中用于标明哪些属性是另一个知乎对象的，
类里的定义只是为了方便构建文档。真正返回对象的操作均由这一装饰器完成。

..  automodule:: zhihu_oauth.zhcls.other
    :members:
    :undoc-members:
    :special-members:
